MetroComboBox<T extends Object> class
A controlled, keyboard-navigable Metro drop-down selection field.
The application owns value. Choosing an enabled item invokes onChanged and closes the popup. A null onChanged, an empty item list, or a list with no enabled items disables the field.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- MetroComboBox
Constructors
-
MetroComboBox({required List<
MetroComboBoxItem< items, T? value, ValueChanged<T> >T?> ? onChanged, Widget? placeholder, Widget? disabledPlaceholder, MetroComboBoxSelectedItemBuilder<T> ? selectedItemBuilder, Widget? icon, MetroComboBoxStyle? style, FocusNode? focusNode, bool autofocus = false, bool preferBelow = true, String? semanticLabel, Key? key}) -
const
Properties
- autofocus → bool
-
final
- disabledPlaceholder → Widget?
-
final
- focusNode → FocusNode?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Widget?
-
final
-
items
→ List<
MetroComboBoxItem< T> > -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onChanged
→ ValueChanged<
T?> ? -
final
- placeholder → Widget?
-
final
- preferBelow → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
selectedItemBuilder
→ MetroComboBoxSelectedItemBuilder<
T> ? -
final
- semanticLabel → String?
-
final
- style → MetroComboBoxStyle?
-
final
- value → T?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< MetroComboBox< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited