MetroFlipViewNavigationVisibility enum

Controls when FlipView previous and next buttons are displayed.

Inheritance
Available extensions

Values

auto → const MetroFlipViewNavigationVisibility

Shows navigation while the FlipView is hovered or contains focus.

always → const MetroFlipViewNavigationVisibility

Keeps every currently available navigation button visible.

hidden → const MetroFlipViewNavigationVisibility

Hides navigation buttons without disabling swipe or keyboard input.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MetroFlipViewNavigationVisibility>
A constant List of the values in this enum, in order of their declaration.