MetroTextFieldThemeData class

Application-level text-field theme values.

Annotations

Constructors

MetroTextFieldThemeData({MetroTextFieldStyle? style})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style MetroTextFieldStyle?
final

Methods

copyWith({MetroTextFieldStyle? style}) MetroTextFieldThemeData
merge(MetroTextFieldThemeData? other) MetroTextFieldThemeData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited